===============================
Tradenity Python SDK
===============================

Python SDK for the Tradenity ecommerce REST API

* Free software: Apache license
* Documentation: (COMING SOON!) https://tradenity.readthedocs.org.

Features
--------

* TODO
